/*-
 * Copyright 2020 Hochschule für Technik Stuttgart
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.hft.stuttgart.quality.model;

import org.citygml4j.builder.copy.CopyBuilder;
import org.citygml4j.model.citygml.ade.binding.ADEModelObject;
import org.citygml4j.model.common.visitor.FeatureFunctor;
import org.citygml4j.model.common.visitor.FeatureVisitor;
import org.citygml4j.model.common.visitor.GMLFunctor;
import org.citygml4j.model.common.visitor.GMLVisitor;
import org.citygml4j.model.gml.feature.AbstractFeature;
import org.citygml4j.model.gml.geometry.primitives.DirectPosition;

public class ConsecutivePointsSame extends AbstractFeature implements ValidationError, ADEModelObject {
	
	private static final long serialVersionUID = -838421312521561747L;
	
	private String linearRingId;
	private DirectPosition vertex1;
	private DirectPosition vertex2;
	
	public void setLinearRingId(String linearRingId) {
		this.linearRingId = linearRingId;
	}
	
	public void setVertex1(DirectPosition vertex1) {
		this.vertex1 = vertex1;
	}
	
	public void setVertex2(DirectPosition vertex2) {
		this.vertex2 = vertex2;
	}
	
	public String getLinearRingId() {
		return linearRingId;
	}
	
	public DirectPosition getVertex1() {
		return vertex1;
	}
	
	public DirectPosition getVertex2() {
		return vertex2;
	}

	@Override
	public String toString() {
		return "ConsecutivePointsSame [linearRingId=" + linearRingId + ", vertex1=" + vertex1 + ", vertex2=" + vertex2
				+ "]";
	}

	@Override
	public Object copy(CopyBuilder copyBuilder) {
		return copyTo(new ConsecutivePointsSame(), copyBuilder);
	}

	@Override
	public void accept(FeatureVisitor visitor) {
		visitor.visit(this);
	}

	@Override
	public <T> T accept(FeatureFunctor<T> visitor) {
		return visitor.apply(this);
	}

	@Override
	public void accept(GMLVisitor visitor) {
		visitor.visit(this);
	}

	@Override
	public <T> T accept(GMLFunctor<T> visitor) {
		return visitor.apply(this);
	}

}
