/*-
 * Copyright 2020 Hochschule für Technik Stuttgart
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.hft.stuttgart.quality.model;

import org.citygml4j.builder.copy.CopyBuilder;
import org.citygml4j.model.citygml.ade.binding.ADEModelObject;
import org.citygml4j.model.common.visitor.FeatureFunctor;
import org.citygml4j.model.common.visitor.FeatureVisitor;
import org.citygml4j.model.common.visitor.GMLFunctor;
import org.citygml4j.model.common.visitor.GMLVisitor;
import org.citygml4j.model.gml.feature.AbstractFeature;

public class IntersectingRings extends AbstractFeature implements ValidationError, ADEModelObject {

	private static final long serialVersionUID = 7668529369582991408L;
	
	private String polygonId;
	private String linearRingId1;
	private String linearRingId2;

	public void setPolygonId(String polygonId) {
		this.polygonId = polygonId;
	}

	public void setLinearRingId1(String linearRingId1) {
		this.linearRingId1 = linearRingId1;
	}

	public void setLinearRingId2(String linearRingId2) {
		this.linearRingId2 = linearRingId2;
	}

	public String getPolygonId() {
		return polygonId;
	}

	public String getLinearRingId1() {
		return linearRingId1;
	}

	public String getLinearRingId2() {
		return linearRingId2;
	}

	@Override
	public String toString() {
		return "IntersectingRings [polygonId=" + polygonId + ", linearRingId1=" + linearRingId1 + ", linearRingId2="
				+ linearRingId2 + "]";
	}

	@Override
	public Object copy(CopyBuilder copyBuilder) {
		return copyTo(new IntersectingRings(), copyBuilder);
	}

	@Override
	public void accept(FeatureVisitor visitor) {
		visitor.visit(this);
	}

	@Override
	public <T> T accept(FeatureFunctor<T> visitor) {
		return visitor.apply(this);
	}

	@Override
	public void accept(GMLVisitor visitor) {
		visitor.visit(this);
	}

	@Override
	public <T> T accept(GMLFunctor<T> visitor) {
		return visitor.apply(this);
	}
}
