/*-
 * Copyright 2020 Hochschule für Technik Stuttgart
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.hft.stuttgart.quality.model;

import java.util.ArrayList;
import java.util.List;

import org.citygml4j.builder.copy.CopyBuilder;
import org.citygml4j.model.citygml.ade.binding.ADEModelObject;
import org.citygml4j.model.common.visitor.FeatureFunctor;
import org.citygml4j.model.common.visitor.FeatureVisitor;
import org.citygml4j.model.common.visitor.GMLFunctor;
import org.citygml4j.model.common.visitor.GMLVisitor;
import org.citygml4j.model.gml.feature.AbstractFeature;

import de.hft.stuttgart.quality.model.jaxb.Component;

public class MultipleConnectedComponents extends AbstractFeature implements ValidationError, ADEModelObject {

	private static final long serialVersionUID = -4199420154182053060L;

	private String geometryId;
	
	private List<Component> components;
	
	public void setGeometryId(String geometryId) {
		this.geometryId = geometryId;
	}
	
	public String getGeometryId() {
		return geometryId;
	}
	
	public boolean isSetComponents() {
		return components != null && !components.isEmpty();
	}
	
	public List<Component> getComponents() {
		if (components == null) {
			components = new ArrayList<>();
		}
		return components;
	}
	
	@Override
	public Object copy(CopyBuilder copyBuilder) {
		return copyTo(new MultipleConnectedComponents(), copyBuilder);
	}

	@Override
	public void accept(FeatureVisitor visitor) {
		visitor.visit(this);
	}

	@Override
	public <T> T accept(FeatureFunctor<T> visitor) {
		return visitor.apply(this);
	}

	@Override
	public void accept(GMLVisitor visitor) {
		visitor.visit(this);
	}

	@Override
	public <T> T accept(GMLFunctor<T> visitor) {
		return visitor.apply(this);
	}
}
