/*-
 * Copyright 2020 Hochschule für Technik Stuttgart
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.hft.stuttgart.quality.model;

import org.citygml4j.builder.copy.CopyBuilder;
import org.citygml4j.model.citygml.ade.binding.ADEModelObject;
import org.citygml4j.model.common.visitor.FeatureFunctor;
import org.citygml4j.model.common.visitor.FeatureVisitor;
import org.citygml4j.model.common.visitor.GMLFunctor;
import org.citygml4j.model.common.visitor.GMLVisitor;
import org.citygml4j.model.gml.feature.AbstractFeature;
import org.citygml4j.model.gml.geometry.primitives.DirectPosition;
import org.citygml4j.model.gml.measures.Length;

public class NonPlanarDistancePlane extends AbstractFeature implements ValidationError, ADEModelObject {

	private static final long serialVersionUID = -3428574131554438219L;
	
	private String polygonId;
	private DirectPosition vertex;
	private Length distance;

	public void setPolygonId(String polygonId) {
		this.polygonId = polygonId;
	}

	public void setVertex(DirectPosition vertex) {
		this.vertex = vertex;
	}

	public void setDistance(Length distance) {
		this.distance = distance;
	}

	public String getPolygonId() {
		return polygonId;
	}

	public DirectPosition getVertex() {
		return vertex;
	}

	public Length getDistance() {
		return distance;
	}

	@Override
	public String toString() {
		return "NonPlanarDistancePlane [polygonId=" + polygonId + ", vertex=" + vertex + ", distance=" + distance + "]";
	}

	@Override
	public Object copy(CopyBuilder copyBuilder) {
		return copyTo(new NonPlanarDistancePlane(), copyBuilder);
	}

	@Override
	public void accept(FeatureVisitor visitor) {
		visitor.visit(this);
	}

	@Override
	public <T> T accept(FeatureFunctor<T> visitor) {
		return visitor.apply(this);
	}

	@Override
	public void accept(GMLVisitor visitor) {
		visitor.visit(this);
	}

	@Override
	public <T> T accept(GMLFunctor<T> visitor) {
		return visitor.apply(this);
	}
}
