/*-
 * Copyright 2020 Hochschule für Technik Stuttgart
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.hft.stuttgart.quality.model;

import java.util.ArrayList;
import java.util.List;

import org.citygml4j.builder.copy.CopyBuilder;
import org.citygml4j.model.citygml.ade.binding.ADEModelObject;
import org.citygml4j.model.common.visitor.FeatureFunctor;
import org.citygml4j.model.common.visitor.FeatureVisitor;
import org.citygml4j.model.common.visitor.GMLFunctor;
import org.citygml4j.model.common.visitor.GMLVisitor;
import org.citygml4j.model.gml.feature.AbstractFeature;

public class PolygonWrongOrientation extends AbstractFeature implements ValidationError, ADEModelObject {

	private static final long serialVersionUID = 1128689472694838648L;
	
	private String geometryId;
	private List<Edge> edges;

	public void setGeometryId(String geometryId) {
		this.geometryId = geometryId;
	}

	public String getGeometryId() {
		return geometryId;
	}
	
	public boolean isSetEdges() {
		return edges != null && !edges.isEmpty();
	}
	
	public List<Edge> getEdges() {
		if (edges == null) {
			edges = new ArrayList<>();
		}
		return edges;
	}

	@Override
	public String toString() {
		return "PolygonWrongOrientation [geometryId=" + geometryId + ", edges=" + edges + "]";
	}

	@Override
	public Object copy(CopyBuilder copyBuilder) {
		return copyTo(new PolygonWrongOrientation(), copyBuilder);
	}

	@Override
	public void accept(FeatureVisitor visitor) {
		visitor.visit(this);
	}

	@Override
	public <T> T accept(FeatureFunctor<T> visitor) {
		return visitor.apply(this);
	}

	@Override
	public void accept(GMLVisitor visitor) {
		visitor.visit(this);
	}

	@Override
	public <T> T accept(GMLFunctor<T> visitor) {
		return visitor.apply(this);
	}
}
