/*-
 * Copyright 2020 Hochschule für Technik Stuttgart
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.hft.stuttgart.quality.model;

import org.citygml4j.builder.copy.CopyBuilder;
import org.citygml4j.model.citygml.ade.binding.ADEModelObject;
import org.citygml4j.model.common.visitor.FeatureFunctor;
import org.citygml4j.model.common.visitor.FeatureVisitor;
import org.citygml4j.model.common.visitor.GMLFunctor;
import org.citygml4j.model.common.visitor.GMLVisitor;
import org.citygml4j.model.gml.feature.AbstractFeature;
import org.citygml4j.model.gml.geometry.primitives.DirectPosition;

import de.hft.stuttgart.quality.model.jaxb.RingSelfIntType;

public class RingSelfIntersection extends AbstractFeature implements ValidationError, ADEModelObject {

	private static final long serialVersionUID = -4426615638983209222L;
	
	private String linearRingId;
	private RingSelfIntType type;
	private Edge edge1;
	private Edge edge2;
	private DirectPosition vertex1;
	private DirectPosition vertex2;

	public void setLinearRingId(String linearRingId) {
		this.linearRingId = linearRingId;
	}

	public void setType(RingSelfIntType type) {
		this.type = type;
	}

	public void setEdge1(Edge edge1) {
		this.edge1 = edge1;
	}

	public void setEdge2(Edge edge2) {
		this.edge2 = edge2;
	}

	public void setVertex1(DirectPosition vertex1) {
		this.vertex1 = vertex1;
	}
	
	public void setVertex2(DirectPosition vertex2) {
		this.vertex2 = vertex2;
	}

	public String getLinearRingId() {
		return linearRingId;
	}

	public RingSelfIntType getType() {
		return type;
	}

	public Edge getEdge1() {
		return edge1;
	}

	public Edge getEdge2() {
		return edge2;
	}

	public DirectPosition getVertex1() {
		return vertex1;
	}
	
	public DirectPosition getVertex2() {
		return vertex2;
	}

	@Override
	public String toString() {
		return "RingSelfIntersection [linearRingId=" + linearRingId + ", type=" + type + ", edge1=" + edge1 + ", edge2="
				+ edge2 + ", vertex1=" + vertex1 + ", vertex2=" + vertex2 + "]";
	}

	@Override
	public Object copy(CopyBuilder copyBuilder) {
		return copyTo(new RingSelfIntersection(), copyBuilder);
	}

	@Override
	public void accept(FeatureVisitor visitor) {
		visitor.visit(this);
	}

	@Override
	public <T> T accept(FeatureFunctor<T> visitor) {
		return visitor.apply(this);
	}

	@Override
	public void accept(GMLVisitor visitor) {
		visitor.visit(this);
	}

	@Override
	public <T> T accept(GMLFunctor<T> visitor) {
		return visitor.apply(this);
	}

}
