/*-
 * Copyright 2020 Hochschule für Technik Stuttgart
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.hft.stuttgart.quality.model;

import org.citygml4j.builder.copy.CopyBuilder;
import org.citygml4j.model.citygml.ade.binding.ADEModelObject;
import org.citygml4j.model.common.visitor.FeatureFunctor;
import org.citygml4j.model.common.visitor.FeatureVisitor;
import org.citygml4j.model.common.visitor.GMLFunctor;
import org.citygml4j.model.common.visitor.GMLVisitor;
import org.citygml4j.model.gml.feature.AbstractFeature;

public class SolidSelfIntersection extends AbstractFeature implements ValidationError, ADEModelObject {

	private static final long serialVersionUID = 4086097021438848040L;

	private String geometryId;
	private String polygonId1;
	private String polygonId2;

	public String getGeometryId() {
		return geometryId;
	}

	public void setGeometryId(String geometryId) {
		this.geometryId = geometryId;
	}

	public String getPolygonId1() {
		return polygonId1;
	}

	public void setPolygonId1(String polygonId1) {
		this.polygonId1 = polygonId1;
	}

	public String getPolygonId2() {
		return polygonId2;
	}

	public void setPolygonId2(String polygonId2) {
		this.polygonId2 = polygonId2;
	}

	@Override
	public String toString() {
		return "SolidSelfIntersection [geometryId=" + geometryId + ", polygonId1=" + polygonId1 + ", polygonId2="
				+ polygonId2 + "]";
	}

	@Override
	public Object copy(CopyBuilder copyBuilder) {
		return copyTo(new SolidSelfIntersection(), copyBuilder);
	}

	@Override
	public void accept(FeatureVisitor visitor) {
		visitor.visit(this);
	}

	@Override
	public <T> T accept(FeatureFunctor<T> visitor) {
		return visitor.apply(this);
	}

	@Override
	public void accept(GMLVisitor visitor) {
		visitor.visit(this);
	}

	@Override
	public <T> T accept(GMLFunctor<T> visitor) {
		return visitor.apply(this);
	}
}
