/*-
 * Copyright 2020 Hochschule für Technik Stuttgart
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.hft.stuttgart.quality.model.jaxb;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;

import de.hft.stuttgart.quality.QualityADEModule;

@XmlRegistry
public class ObjectFactory {

	private static final QName VALIDATION_QNAME = new QName(QualityADEModule.NAMESPACE_URI, "validation");
	private static final QName VALIDATION_RESULT_QNAME = new QName(QualityADEModule.NAMESPACE_URI, "validationResult");
	
	public ValidationType createValidationType() {
		return new ValidationType();
	}
	
	public ValidationResultType createValidationResultType() {
		return new ValidationResultType();
	}
	
	public ConsecutivePointsSameType createConsecutivePointsSameType() {
		return new ConsecutivePointsSameType();
	}
	
	public TooFewPointsType createTooFewPointsType() {
		return new TooFewPointsType();
	}

	@XmlElementDecl(namespace = QualityADEModule.NAMESPACE_URI, name = "validation", substitutionHeadNamespace = "http://www.opengis.net/citygml/2.0", substitutionHeadName = "_GenericApplicationPropertyOfCityModel")
	public JAXBElement<ValidationType> createValidationType(ValidationType type) {
		return new JAXBElement<>(VALIDATION_QNAME, ValidationType.class, type);
	}
	
	@XmlElementDecl(namespace = QualityADEModule.NAMESPACE_URI, name = "validationResult", substitutionHeadNamespace = "http://www.opengis.net/citygml/2.0", substitutionHeadName = "_GenericApplicationPropertyOfCityObject")
	public JAXBElement<ValidationResultType> createValidationResultType(ValidationResultType type) {
		return new JAXBElement<>(VALIDATION_RESULT_QNAME, ValidationResultType.class, type);
	}

	public RingSelfIntersectionType createRingSelfIntersectionType() {
		return new RingSelfIntersectionType();
	}

}
