/*-
 * Copyright 2020 Hochschule für Technik Stuttgart
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.hft.stuttgart.quality.model.jaxb;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;

@XmlType(name = "requirement")
@XmlAccessorType(XmlAccessType.FIELD)
public class Requirement implements Serializable {

	private static final long serialVersionUID = 8493047783215253763L;

	@XmlAttribute
	private RequirementId name;

	@XmlAttribute
	private boolean enabled;

	@XmlElement(name = "parameter")
	private List<Parameter> parameters;

	public RequirementId getName() {
		return name;
	}

	public List<Parameter> getParameters() {
		if (parameters == null) {
			parameters = new ArrayList<>(2);
		}
		return parameters;
	}

	public boolean isEnabled() {
		return enabled;
	}

	public void setName(RequirementId name) {
		this.name = name;
	}
	
	public void setEnabled(boolean enabled) {
		this.enabled = enabled;
	}

	@Override
	public String toString() {
		return "Requirement [name=" + name + ", enabled=" + enabled + ", parameters=" + parameters + "]";
	}

}
