/*-
 * Copyright 2020 Hochschule für Technik Stuttgart
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.hft.stuttgart.quality.model.jaxb;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementWrapper;

@XmlAccessorType(XmlAccessType.FIELD)
public class Statistics implements Serializable {

	private static final long serialVersionUID = 2250094686994310986L;

	private FeatureStatistics numErrorBuildings;
	private FeatureStatistics numErrorVegetation;
	private FeatureStatistics numErrorLandObjects;
	private FeatureStatistics numErrorBridgeObjects;
	private FeatureStatistics numErrorWaterObjects;
	private FeatureStatistics numErrorTransportation;

	@XmlElementWrapper(name = "errorStatistics")
	@XmlElement(name = "error")
	private List<ErrorStatistics> errorStatistics;

	public List<ErrorStatistics> getErrorStatistics() {
		if (errorStatistics == null) {
			errorStatistics = new ArrayList<>();
		}
		return errorStatistics;
	}

	public FeatureStatistics getNumErrorBridgeObjects() {
		return numErrorBridgeObjects;
	}

	public FeatureStatistics getNumErrorBuildings() {
		return numErrorBuildings;
	}

	public FeatureStatistics getNumErrorLandObjects() {
		return numErrorLandObjects;
	}

	public FeatureStatistics getNumErrorTransportation() {
		return numErrorTransportation;
	}

	public FeatureStatistics getNumErrorVegetation() {
		return numErrorVegetation;
	}

	public FeatureStatistics getNumErrorWaterObjects() {
		return numErrorWaterObjects;
	}

	public void setNumErrorBridgeObjects(FeatureStatistics numErrorBridgeObjects) {
		this.numErrorBridgeObjects = numErrorBridgeObjects;
	}

	public void setNumErrorBuildings(FeatureStatistics numErrorBuildings) {
		this.numErrorBuildings = numErrorBuildings;
	}

	public void setNumErrorLandObjects(FeatureStatistics numErrorLandObjects) {
		this.numErrorLandObjects = numErrorLandObjects;
	}

	public void setNumErrorTransportation(FeatureStatistics numErrorTransportation) {
		this.numErrorTransportation = numErrorTransportation;
	}

	public void setNumErrorVegetation(FeatureStatistics numErrorVegetation) {
		this.numErrorVegetation = numErrorVegetation;
	}

	public void setNumErrorWaterObjects(FeatureStatistics numErrorWaterObjects) {
		this.numErrorWaterObjects = numErrorWaterObjects;
	}

}
